package cn.com.infosec.asn1;

import cn.com.infosec.util.io.Streams;
import java.io.EOFException;
import java.io.InputStream;

class DefiniteLengthInputStream extends LimitedInputStream {
   private static final byte[] EMPTY_BYTES = new byte[0];
   private int _length;

   DefiniteLengthInputStream(InputStream in, int length) {
      super(in);
      if (length >= 0) {
         this._length = length;
      } else {
         throw new IllegalArgumentException("negative lengths not allowed");
      }
   }

   public int read() {
      if (this._length > 0) {
         int var1;
         if ((var1 = super._in.read()) >= 0) {
            --this._length;
            return var1;
         } else {
            throw new EOFException();
         }
      } else {
         this.setParentEofDetect(true);
         return -1;
      }
   }

   public int read(byte[] buf, int off, int len) {
      int var4;
      if ((var4 = this._length) > 0) {
         len = Math.min(len, var4);
         int buf1;
         if ((buf1 = super._in.read(buf, off, len)) >= 0) {
            this._length -= buf1;
            return buf1;
         } else {
            throw new EOFException();
         }
      } else {
         this.setParentEofDetect(true);
         return -1;
      }
   }

   byte[] toByteArray() {
      int var1;
      byte[] var2;
      if ((var1 = this._length) > 0) {
         var2 = new byte[var1];
         if (Streams.readFully(super._in, var2) < this._length) {
            throw new EOFException();
         }

         this._length = 0;
      } else {
         var2 = EMPTY_BYTES;
      }

      this.setParentEofDetect(true);
      return var2;
   }
}
